@@ -29,6 +29,8 @@ class SDKException(Exception):
         self.message = self.__class__.__name__ if message is None else message
         self.extra_data = extra_data
         super(SDKException, self).__init__(self.message)
+
+
 OpenStackCloudException = SDKException
 
 
@@ -92,7 +94,7 @@ class HttpException(SDKException, _rex.HTTPError):
         # and we should use it. If it is 'Error', then we should construct a
         # better message from the information we do have.
         if not self.url or self.message == 'Error':
-            return super(HttpException, self).__str__()
+            return self.message
         if self.url:
             remote_error = "{source} Error for url: {url}".format(
                 source=self.source, url=self.url)
