@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.identity import identity_service
 from openstack import resource
 
 
@@ -18,13 +17,13 @@ class RoleAssignment(resource.Resource):
     resource_key = 'role_assignment'
     resources_key = 'role_assignments'
     base_path = '/role_assignments'
-    service = identity_service.IdentityService()
 
     # capabilities
     allow_list = True
 
     _query_mapping = resource.QueryParameters(
-        'effective', 'include_names', 'include_subtree',
+        'group_id', 'role_id', 'scope_domain_id', 'scope_project_id',
+        'user_id', 'effective', 'include_names', 'include_subtree',
         role_id='role.id', user_id='user.id', group_id='group.id',
         scope_project_id='scope.project.id', scope_domain_id='scope.domain.id',
         scope_system='scope.system',
