@@ -23,10 +23,10 @@ from openstack.compute.v2 import server_group
 from openstack.compute.v2 import server_interface
 from openstack.compute.v2 import server_ip
 from openstack.compute.v2 import service
-from openstack.tests.unit import test_proxy_base2
+from openstack.tests.unit import test_proxy_base
 
 
-class TestComputeProxy(test_proxy_base2.TestProxyBase):
+class TestComputeProxy(test_proxy_base.TestProxyBase):
     def setUp(self):
         super(TestComputeProxy, self).setUp()
         self.proxy = _proxy.Proxy(self.session)
@@ -35,8 +35,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
         self.verify_find(self.proxy.find_extension, extension.Extension)
 
     def test_extensions(self):
-        self.verify_list_no_kwargs(self.proxy.extensions, extension.Extension,
-                                   paginated=False)
+        self.verify_list_no_kwargs(self.proxy.extensions, extension.Extension)
 
     def test_flavor_create(self):
         self.verify_create(self.proxy.create_flavor, flavor.Flavor)
@@ -55,13 +54,11 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
 
     def test_flavors_detailed(self):
         self.verify_list(self.proxy.flavors, flavor.FlavorDetail,
-                         paginated=True,
                          method_kwargs={"details": True, "query": 1},
                          expected_kwargs={"query": 1})
 
     def test_flavors_not_detailed(self):
         self.verify_list(self.proxy.flavors, flavor.Flavor,
-                         paginated=True,
                          method_kwargs={"details": False, "query": 1},
                          expected_kwargs={"query": 1})
 
@@ -79,13 +76,11 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
 
     def test_images_detailed(self):
         self.verify_list(self.proxy.images, image.ImageDetail,
-                         paginated=True,
                          method_kwargs={"details": True, "query": 1},
                          expected_kwargs={"query": 1})
 
     def test_images_not_detailed(self):
         self.verify_list(self.proxy.images, image.Image,
-                         paginated=True,
                          method_kwargs={"details": False, "query": 1},
                          expected_kwargs={"query": 1})
 
@@ -105,8 +100,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
         self.verify_get(self.proxy.get_keypair, keypair.Keypair)
 
     def test_keypairs(self):
-        self.verify_list_no_kwargs(self.proxy.keypairs, keypair.Keypair,
-                                   paginated=False)
+        self.verify_list_no_kwargs(self.proxy.keypairs, keypair.Keypair)
 
     def test_limits_get(self):
         self.verify_get(self.proxy.get_limits, limits.Limits, value=[])
@@ -126,7 +120,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
         test_interface.server_id = server_id
 
         # Case1: ServerInterface instance is provided as value
-        self._verify2("openstack.proxy2.BaseProxy._delete",
+        self._verify2("openstack.proxy.Proxy._delete",
                       self.proxy.delete_server_interface,
                       method_args=[test_interface],
                       method_kwargs={"server": server_id},
@@ -136,7 +130,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                                        "ignore_missing": True})
 
         # Case2: ServerInterface ID is provided as value
-        self._verify2("openstack.proxy2.BaseProxy._delete",
+        self._verify2("openstack.proxy.Proxy._delete",
                       self.proxy.delete_server_interface,
                       method_args=[interface_id],
                       method_kwargs={"server": server_id},
@@ -163,7 +157,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
         test_interface.server_id = server_id
 
         # Case1: ServerInterface instance is provided as value
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_server_interface,
                       method_args=[test_interface],
                       method_kwargs={"server": server_id},
@@ -172,7 +166,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                                        "server_id": server_id})
 
         # Case2: ServerInterface ID is provided as value
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_server_interface,
                       method_args=[interface_id],
                       method_kwargs={"server": server_id},
@@ -183,19 +177,19 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
     def test_server_interfaces(self):
         self.verify_list(self.proxy.server_interfaces,
                          server_interface.ServerInterface,
-                         paginated=False, method_args=["test_id"],
+                         method_args=["test_id"],
                          expected_kwargs={"server_id": "test_id"})
 
     def test_server_ips_with_network_label(self):
         self.verify_list(self.proxy.server_ips, server_ip.ServerIP,
-                         paginated=False, method_args=["test_id"],
+                         method_args=["test_id"],
                          method_kwargs={"network_label": "test_label"},
                          expected_kwargs={"server_id": "test_id",
                                           "network_label": "test_label"})
 
     def test_server_ips_without_network_label(self):
         self.verify_list(self.proxy.server_ips, server_ip.ServerIP,
-                         paginated=False, method_args=["test_id"],
+                         method_args=["test_id"],
                          expected_kwargs={"server_id": "test_id",
                                           "network_label": None})
 
@@ -221,18 +215,15 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
 
     def test_servers_detailed(self):
         self.verify_list(self.proxy.servers, server.ServerDetail,
-                         paginated=True,
                          method_kwargs={"details": True,
                                         "changes_since": 1, "image": 2},
                          expected_kwargs={"changes_since": 1, "image": 2})
 
     def test_servers_not_detailed(self):
         self.verify_list(self.proxy.servers, server.Server,
-                         paginated=True,
                          method_kwargs={"details": False,
                                         "changes_since": 1, "image": 2},
-                         expected_kwargs={"paginated": True,
-                                          "changes_since": 1, "image": 2})
+                         expected_kwargs={"changes_since": 1, "image": 2})
 
     def test_server_update(self):
         self.verify_update(self.proxy.update_server, server.Server)
@@ -418,17 +409,22 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                      method_args=["value", 1],
                      expected_kwargs={"length": 1})
 
-    def test_availability_zones(self):
-        self.verify_list_no_kwargs(self.proxy.availability_zones,
-                                   az.AvailabilityZone,
-                                   paginated=False)
+    def test_availability_zones_not_detailed(self):
+        self.verify_list(self.proxy.availability_zones,
+                         az.AvailabilityZone,
+                         method_kwargs={"details": False})
+
+    def test_availability_zones_detailed(self):
+        self.verify_list(self.proxy.availability_zones,
+                         az.AvailabilityZoneDetail,
+                         method_kwargs={"details": True})
 
     def test_get_all_server_metadata(self):
         self._verify2("openstack.compute.v2.server.Server.get_metadata",
                       self.proxy.get_server_metadata,
                       method_args=["value"],
                       method_result=server.Server(id="value", metadata={}),
-                      expected_args=[self.session],
+                      expected_args=[self.proxy],
                       expected_result={})
 
     def test_set_server_metadata(self):
@@ -440,7 +436,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                       method_kwargs=kwargs,
                       method_result=server.Server.existing(id=id,
                                                            metadata=kwargs),
-                      expected_args=[self.session],
+                      expected_args=[self.proxy],
                       expected_kwargs=kwargs,
                       expected_result=kwargs)
 
@@ -449,7 +445,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                       self.proxy.delete_server_metadata,
                       expected_result=None,
                       method_args=["value", "key"],
-                      expected_args=[self.session, "key"])
+                      expected_args=[self.proxy, "key"])
 
     def test_server_group_create(self):
         self.verify_create(self.proxy.create_server_group,
@@ -472,13 +468,15 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                         server_group.ServerGroup)
 
     def test_server_groups(self):
-        self.verify_list(self.proxy.server_groups, server_group.ServerGroup,
-                         paginated=False)
+        self.verify_list(self.proxy.server_groups, server_group.ServerGroup)
 
-    def test_hypervisors(self):
-        self.verify_list_no_kwargs(self.proxy.hypervisors,
-                                   hypervisor.Hypervisor,
-                                   paginated=False)
+    def test_hypervisors_not_detailed(self):
+        self.verify_list(self.proxy.hypervisors, hypervisor.Hypervisor,
+                         method_kwargs={"details": False})
+
+    def test_hypervisors_detailed(self):
+        self.verify_list(self.proxy.hypervisors, hypervisor.HypervisorDetail,
+                         method_kwargs={"details": True})
 
     def test_find_hypervisor(self):
         self.verify_find(self.proxy.find_hypervisor,
@@ -490,8 +488,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
 
     def test_services(self):
         self.verify_list_no_kwargs(self.proxy.services,
-                                   service.Service,
-                                   paginated=False)
+                                   service.Service)
 
     def test_enable_service(self):
         self._verify('openstack.compute.v2.service.Service.enable',
@@ -514,5 +511,6 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
     def test_live_migrate_server(self):
         self._verify('openstack.compute.v2.server.Server.live_migrate',
                      self.proxy.live_migrate_server,
-                     method_args=["value", "host1", "force"],
-                     expected_args=["host1", "force"])
+                     method_args=["value", "host1", False],
+                     expected_args=["host1"],
+                     expected_kwargs={'force': False, 'block_migration': None})
